"""Top-level package for libshipkore."""

__author__ = """Innerkore"""
__email__ = "admin@innerkore.com"
__version__ = "0.4.2"
